#include <iostream>
#include <vector>
#include <algorithm>
#include <cassert>

using ll = long long;
using i128 = __int128;

struct bigint {
  std::vector<int> nr;
  const static int base_digits = 1;
  const static int base = 10;
  void normalize() {
    for (int i = 0; i < (int) nr.size(); i++) {
      if(nr[i] >= base) {
        if (i == (int) nr.size() - 1) {
          nr.push_back(0);
        }
        nr[i + 1] += nr[i] / base;
        nr[i] %= base;
      } else if (nr[i] < 0) {
        nr[i] += base;
        nr[i + 1]--;
      }     
    }
    while (!nr.empty() && nr.back() == 0) {
      nr.pop_back();
    }
  }

  bigint operator + (const bigint &other) const {
    bigint ret;
    for (int i = 0; i < std::max(nr.size(), other.nr.size()); i++) {
      int t = 0;
      if (i < (int) nr.size()) {
        t += nr[i];
      } 
      if (i < (int) other.nr.size()) {
        t += other.nr[i];
      }
      ret.nr.push_back(t);
    }
    ret.normalize();
    return ret;
  };

  friend std::istream& operator >> (std::istream &in, bigint &v) {
    std::string s;
    in >> s;
    int cur = 0;
    int p10 = 1;
    v.nr.clear();
    for (int i = (int) s.size() - 1; i >= 0; i--) {
      cur += p10 * (s[i] - '0');
      p10 *= 10;
      if (p10 == base) {
        v.nr.push_back(cur);
        p10 = 1;
        cur = 0;
      }
    }
    v.nr.push_back(cur);
    v.normalize();
    return in;
  } 
  friend std::ostream& operator << (std::ostream &out, const bigint &v) {
    for (int i = (int) v.nr.size() - 1; i >= 0; i--) {
      if (i != (int) v.nr.size() - 1) {
        int x = v.nr[i];
        int k = 0;
        while (x) {
          k++;
          x /= 10;
        }
        for (int i = 0; i < base_digits - k; i++) {
          out << 0;
        }
      }
      out << v.nr[i];
    }
    return out;
  }
};

int main() {
  #ifdef LOCAL
freopen("input.txt", "r", stdin);
  #endif
  
  std::ios_base::sync_with_stdio(false);
  std::cin.tie(0);
  
  int a, b;
  std::cin >> a >> b;
  std::cout << a + b;

  return 0;
}